==> nextcloud-app-mail-5.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/br.js <==
OC.L10N.register(
    "mail",
    {
    "Important mail" : "Postel pouezus",
    "Set up an account" : "Staliañ ur c'hont",
    "Important" : "Important",
    "Work" : "Labour",
    "Personal" : "Personel",
    "Mail" : "Postel",
    "Save" : "Enrollañ",
    "Connect" : "Kenstagañ",
    "Password required" : "Ger-tremen ret",
    "Name" : "Anv",
    "Password" : "Ger-tremen",
    "None" : "Hini ebet",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "Ger-tremen SMTP",
    "Change name" : "Cheñch env",
    "Cancel" : "Nullañ",
    "Accounts" : "Kontoù",
    "General" : "Hollek",
    "List" : "Roll",
    "Delete" : "Dilemel",
    "Search" : "Klask",
    "Send" : "Kas",
    "Refresh" : "Freskaat",
    "Choose" : "Dibab",
    "Confirm" : "Kadarnañ",
    "Unfavorite" : "Digaretañ",
    "Favorite" : "Pennrollañ",
    "Back" : "Distro",
    "Description" : "Deskrivadur",
    "Create" : "Krouiñ",
    "Select" : "Dibab",
    "Comment" : "Displegadenn",
    "Accept" : "Asantiñ",
    "Remove" : "Lemel",
    "email" : "postel",
    "Important info" : "Titouroù pouezus",
    "Other" : "All",
    "Forward" : "War-raok",
    "Translate" : "Treiñ",
    "Show images" : "Diskouzh ar skeudennoù",
    "Message frame" : "Fram kemenadenn",
    "Move" : "Diplasañ",
    "Loading …" : "O Kargañ ...",
    "Remove account" : "Lemel ar c'hont",
    "Quota" : "Quota",
    "Rename" : "Adenvel",
    "Clear cache" : "Gwalc'hiñ ar c'hache",
    "Reply" : "Respont",
    "Retry" : "Klaskit en dro",
    "Add" : "Ouzhpennañ",
    "Clear" : "Netaat",
    "Close" : "Serriñ",
    "Date" : "Deiz",
    "Tags" : "Klavioù",
    "Actions" : "Oberoù",
    "Client ID" : "ID kliant",
    "User" : "Implijer",
    "Host" : "Ostiz",
    "Port" : "Porzh",
    "Valid until" : "Gwir betek",
    "Submit" : "Kinnig",
    "Account connected" : "Kont kenstaged",
    "All" : "Pep tra",
    "Favorites" : "Pennrolloù",
    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");

==> nextcloud-app-mail-5.1.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/br.js <==
OC.L10N.register(
    "mail",
    {
    "Important mail" : "Postel pouezus",
    "Set up an account" : "Staliañ ur c'hont",
    "Important" : "Important",
    "Work" : "Labour",
    "Personal" : "Personel",
    "Mail" : "Postel",
    "Save" : "Enrollañ",
    "Connect" : "Kenstagañ",
    "Password required" : "Ger-tremen ret",
    "Name" : "Anv",
    "Password" : "Ger-tremen",
    "None" : "Hini ebet",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "Ger-tremen SMTP",
    "Change name" : "Cheñch env",
    "Cancel" : "Nullañ",
    "Accounts" : "Kontoù",
    "General" : "Hollek",
    "List" : "Roll",
    "Delete" : "Dilemel",
    "Search" : "Klask",
    "Send" : "Kas",
    "Refresh" : "Freskaat",
    "Choose" : "Dibab",
    "Confirm" : "Kadarnañ",
    "Unfavorite" : "Digaretañ",
    "Favorite" : "Pennrollañ",
    "Back" : "Distro",
    "Description" : "Deskrivadur",
    "Create" : "Krouiñ",
    "Select" : "Dibab",
    "Comment" : "Displegadenn",
    "Accept" : "Asantiñ",
    "Remove" : "Lemel",
    "email" : "postel",
    "Important info" : "Titouroù pouezus",
    "Other" : "All",
    "Forward" : "War-raok",
    "Translate" : "Treiñ",
    "Show images" : "Diskouzh ar skeudennoù",
    "Message frame" : "Fram kemenadenn",
    "Move" : "Diplasañ",
    "Loading …" : "O Kargañ ...",
    "Remove account" : "Lemel ar c'hont",
    "Quota" : "Quota",
    "Rename" : "Adenvel",
    "Clear cache" : "Gwalc'hiñ ar c'hache",
    "Reply" : "Respont",
    "Retry" : "Klaskit en dro",
    "Add" : "Ouzhpennañ",
    "Clear" : "Netaat",
    "Close" : "Serriñ",
    "Date" : "Deiz",
    "Tags" : "Klavioù",
    "Translate to" : "Treiñ e",
    "Client ID" : "ID kliant",
    "User" : "Implijer",
    "Host" : "Ostiz",
    "Port" : "Porzh",
    "Valid until" : "Gwir betek",
    "Submit" : "Kinnig",
    "Account connected" : "Kont kenstaged",
    "All" : "Pep tra",
    "Favorites" : "Pennrolloù",
    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
    "Actions" : "Oberoù"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
